@@ -126,6 +126,7 @@ const char kPartitionMinimumDiskSpaceRequired[] =
 const char kPartitionRecommendedDiskSpace[] =
     "disk_recommended_space";
 const char kPartitionRootMiniSpace[] = "partition_root_space_required";
+const char kPartitionFullDiskRootPartitionUsage[] = "partition_full_disk_root_partition_usage";
 const char kAutoMountPartitionRootMiniSpace[] = "auto_mount_partition_root_space_required";
 const char kPartitionFullDiskMiniSpace[] = "partition_full_disk_minimum_space";
 const char kPartitionDefaultBootSpace[] = "partition_default_boot_space";
@@ -190,6 +191,9 @@ const char kIfDoRecovery[] = "if_do_recovery";
 // 无人值守时可以通过改选项控制初始备份是否生成
 const char kIsInitRecvoery[] = "is_init_recovery";
 
+// 是否显示创建初始化备份选择框
+const char kIsShowInitRecoveryCheckbox[] = "is_show_init_recovery_checkbox";
+
 // Install progress page
 const char kInstallProgressPageDisableSlide[] =
     "install_progress_page_disable_slide";
@@ -248,6 +252,8 @@ const char kSystemRecoveryBaseSize[] = "system_recovery_base_size";
 
 const char kSystemIsCreateEFI[] = "system_is_create_efi";
 
+const char kEnableChangeRootSize[] = "enable_change_root_size";
+
 }  // namespace installer
 
 #endif  // INSTALLER_SERVICE_SETTINGS_NAME_H
