@@ -77,10 +77,10 @@ void PrepareInstallFrame::updateDescription(const QStringList& descriptions) {
 
 void PrepareInstallFrame::setCreateRecovery(bool isCreate)
 {
-    if (!isCreate) {
-        m_selectCreateRecovery->hide();
-    } else {
+    if (GetSettingsBool(kIsShowInitRecoveryCheckbox) && isCreate) {
         m_selectCreateRecovery->show();
+    } else {
+        m_selectCreateRecovery->hide();
     }
 }
 
@@ -256,6 +256,8 @@ void PrepareInstallFrame::initUI() {
 
   m_selectCreateRecovery = new DCheckBox;
   m_selectCreateRecovery->setChecked(GetSettingsBool(kIsInitRecvoery));
+  m_selectCreateRecovery->setVisible(GetSettingsBool(kIsShowInitRecoveryCheckbox));
+
 
   m_installNvidiaCheck = new QCheckBox;
   m_installNvidiaCheck->setObjectName("check_box");
