@@ -768,6 +768,7 @@ void SystemInfoFormFramePrivate::updatePasswdLevel()
         QPalette palette;
         palette.setColor(QPalette::Text, mapPasswdLevelColor[PasswordManager::instance()->passwdLevel(m_passwordEdit->text())]);
         m_passwdLevelLabel->setPalette(palette);
+        m_passwdLevelLabel->setForegroundRole(QPalette::Text);
         m_passwdLevelLabel->setText(mapPasswdLevel[PasswordManager::instance()->passwdLevel(m_passwordEdit->text())]);
     } else {
         m_passwdLevelLabel->setText("");
@@ -777,6 +778,7 @@ void SystemInfoFormFramePrivate::updatePasswdLevel()
         QPalette palette;
         palette.setColor(QPalette::Text, mapPasswdLevelColor[PasswordManager::instance()->passwdLevel(m_rootPasswordEdit->text())]);
         m_rootPasswdLevelLabel->setPalette(palette);
+        m_rootPasswdLevelLabel->setForegroundRole(QPalette::Text);
         m_rootPasswdLevelLabel->setText(mapPasswdLevel[PasswordManager::instance()->passwdLevel(m_rootPasswordEdit->text())]);
 
     } else {
@@ -825,11 +827,9 @@ void SystemInfoFormFramePrivate::initBoolvariable()
 
 bool SystemInfoFormFramePrivate::validateUsername(QString& msg)
 {
-    const QString reserved_username_file = GetReservedUsernameFile();
     const int     min_len = GetSettingsInt(kSystemInfoUsernameMinLen);
     const int     max_len = GetSettingsInt(kSystemInfoUsernameMaxLen);
-    const ValidateUsernameState state = ValidateUsername(m_usernameEdit->text()
-                                                         , reserved_username_file, min_len, max_len);
+    const ValidateUsernameState state = ValidateUsername(m_usernameEdit->text(), min_len, max_len);
     switch (state) {
     case ValidateUsernameState::ReservedError: {
         msg = ::QObject::tr("This username already exists");
@@ -840,14 +840,14 @@ bool SystemInfoFormFramePrivate::validateUsername(QString& msg)
         return false;
     }
     case ValidateUsernameState::EmptyError:  // fall through
+    case ValidateUsernameState::Digital:
     case ValidateUsernameState::InvalidCharError: {
-        msg = ::QObject::tr("Username can only contain lowercase letters, numbers and symbols (_-)");
+        msg = ::QObject::tr("Username must start with letters or numbers, only contain letters, numbers, dashes (-) and underscores (_), and cannot use numbers alone");
         return false;
     }
     case ValidateUsernameState::TooLongError:  // fall through
     case ValidateUsernameState::TooShortError: {
-        msg = ::QObject::tr("Please input a username longer than %1 characters and "
-                 "shorter than %2 characters")
+        msg = ::QObject::tr("Username must be between %1 and %2 characters")
                 .arg(min_len)
                 .arg(max_len);
         return false;
@@ -873,7 +873,7 @@ bool SystemInfoFormFramePrivate::validateHostname(QString& msg)
         return false;
     }
     case ValidateHostnameState::InvalidChar: {
-        msg = ::QObject::tr("Computer name is invalid");
+        msg = ::QObject::tr("Computer name can only contain letters, numbers, and dashes (-), and cannot start or end with a dash (-)");
         return false;
     }
     case ValidateHostnameState::ReservedError: {
@@ -888,6 +888,13 @@ bool SystemInfoFormFramePrivate::validateHostname(QString& msg)
                 .arg(kHostnameMaxLen);
         return false;
     }
+    case ValidateHostnameState::LabelTooLongError: {
+        msg = ::QObject::tr("Please input a computer name longer than %1 characters and "
+                 "shorter than %2 characters")
+                .arg(kHostnameMinLen)
+                .arg(LabelMaxLen);
+        return false;
+    }
     case ValidateHostnameState::Ok: {
         // Pass
         break;
@@ -995,14 +1002,14 @@ void SystemInfoFormFramePrivate::onUsernameEdited()
     if (!m_isHostnameEditedManually_ &&
             !GetSettingsBool(kSystemInfoLockHostname)) {
         // Update hostname based on username.
-        const QString username = m_usernameEdit->text();
+        QString username = m_usernameEdit->text();
         if (username.isEmpty()) {
             m_hostnameEdit->setText("");
         }
         else {
             // Add suffix to username
             m_hostnameEdit->setText(
-                        username + GetSettingsString(kSystemInfoHostnameAutoSuffix));
+                        username.replace("_","") + GetSettingsString(kSystemInfoHostnameAutoSuffix));
         }
     }
 }
