@@ -30,6 +30,9 @@
 #include <DStandardItem>
 #include <DBackgroundGroup>
 #include <DTitlebar>
+#include <QWindow>
+#include <QScreen>
+#include <QObject>
 
 #include "ui/interfaces/frameinterface.h"
 #include "base/file_util.h"
@@ -43,7 +46,6 @@
 #include "third_party/global_shortcut/global_shortcut.h"
 #include "ui/delegates/language_delegate.h"
 #include "ui/delegates/main_window_util.h"
-#include "ui/frames/confirm_quit_frame.h"
 #include "ui/frames/control_panel_frame.h"
 #include "ui/frames/disk_space_insufficient_frame.h"
 #include "ui/frames/install_progress_frame.h"
@@ -60,6 +62,7 @@
 #include "ui/frames/repair_system_frame.h"
 #include "ui/frames/inner/system_info_keyboard_frame.h"
 #include "ui/frames/networkframe.h"
+#include "ui/frames/warnning_frame.h"
 
 #include "ui/utils/widget_util.h"
 #include "ui/widgets/pointer_button.h"
@@ -82,7 +85,6 @@ namespace installer {
 MainWindow::MainWindow(QWidget* parent)
     : DMainWindow(parent),
       FrameProxyInterface(),
-      shadow_widget(new ShadowWidget),
       pages_(),
       prev_page_(PageId::NullId),
       current_page_(PageId::NullId),
@@ -100,6 +102,10 @@ MainWindow::MainWindow(QWidget* parent)
     titleBar->installEventFilter(this);
     setWindowFlags(windowFlags() & ~Qt::WindowCloseButtonHint & ~Qt::WindowMinMaxButtonsHint);
 
+#ifndef QT_DEBUG
+    setWindowFlags(windowFlags() | Qt::WindowStaysOnTopHint | Qt::X11BypassWindowManagerHint);  // 设置窗口不受窗管管控，本地debug调试的时候不生效
+#endif // QT_DEBUG
+
     titlebar()->setMenuVisible(false);
     titlebar()->setFullScreenButtonVisible(false);
 
@@ -139,28 +145,52 @@ MainWindow::MainWindow(QWidget* parent)
     }
 }
 
-void MainWindow::fullscreen() {
-  if (GetSettingsBool(kPartitionDoAutoPart)) {
-    // Read default locale from settings.ini and go to InstallProgressFrame.
-    // 当配置了页面跳过和自动安装时，对于磁盘空间检测的异常需要有异常提示界面
-    // current_page_ = PageId::PartitionId;
+void MainWindow::setup() {
+    if (GetSettingsBool(kPartitionDoAutoPart)) {
+        // Read default locale from settings.ini and go to InstallProgressFrame.
+        // 当配置了页面跳过和自动安装时，对于磁盘空间检测的异常需要有异常提示界面
+        // current_page_ = PageId::PartitionId;
 
-    // Set language.
-    QTranslator* translator = new QTranslator(this);
-    const QString locale(ReadLocale());
-    translator->load(GetLocalePath(locale));
-    qApp->installTranslator(translator);
-  }
-
-    this->setFixedSize(ScreenAdaptationManager::instance()->primaryAvailableGeometry().size());
+        // Set language.
+        QTranslator* translator = new QTranslator(this);
+        const QString locale(ReadLocale());
+        translator->load(GetLocalePath(locale));
+        qApp->installTranslator(translator);
+    }
 
     if (GetSettingsBool(kPartitionDoAutoPart) || GetSettingsBool("DI_LUPIN")) {
-    // In auto-install mode, partitioning is done in hook script.
-    // So notify InstallProgressFrame to run hooks directly.
-    partition_frame_->autoPart();
-  }
+        // In auto-install mode, partitioning is done in hook script.
+        // So notify InstallProgressFrame to run hooks directly.
+        partition_frame_->autoPart();
+    }
 }
 
+void MainWindow::setScreen(QScreen *screen)
+{
+    if (screen == m_screen)
+        return;
+
+    if (m_screen) {
+        disconnect(m_screen, &QScreen::geometryChanged, this, &MainWindow::updateGeometry);
+    }
+
+    if (screen) {
+        connect(screen, &QScreen::geometryChanged, this, &MainWindow::updateGeometry);
+    }
+
+    m_screen = screen;
+
+    if (m_screen)
+        updateGeometry();
+}
+
+void MainWindow::updateGeometry()
+{
+    setGeometry(m_screen->availableGeometry());
+    setFixedSize(m_screen->availableSize());
+}
+
+
 void MainWindow::scanDevicesAndTimezone() {
     ScanNetDevice();  // 扫描网络设备
 
@@ -325,16 +355,16 @@ void MainWindow::showChildFrame(BaseFrameInterface* childFrameInterface)
         return;
     }
     shadow_widget->setContent(childFrameInterface);
-    shadow_widget->setParent(this);
-    shadow_widget->setGeometry(rect());
+    shadow_widget->setAttribute(Qt::WA_ShowModal, true);
     shadow_widget->raise();
     shadow_widget->show();
+    shadow_widget->repaint();
+    repaint();
 }
 
 void MainWindow::hideChildFrame() const
 {
-    shadow_widget->eraseContent();
-    shadow_widget->hide();
+    shadow_widget->close();
 }
 
 void MainWindow::showExtFrameFullscreen(BaseFrameInterface* childFrameInterface)
@@ -397,22 +427,33 @@ bool MainWindow::eventFilter(QObject *target, QEvent *event)
 
 void MainWindow::onCloseEvent()
 {
-    confirm_quit_frame_->display();
+    showChildFrame(confirm_quit_frame_);
 }
 
 void MainWindow::changeEvent(QEvent *event)
 {
     if (event->type() == QEvent::LanguageChange) {
         for (int i = 0; i < m_frameLabelsModel->rowCount(); ++i) {
-            QStandardItem* item = m_frameLabelsModel->item(i);
+            DStandardItem* item =  dynamic_cast<DStandardItem*>(m_frameLabelsModel->item(i));
             FrameInterface* frame = getFrameInterface(item);
             if (frame) {
-                item->setText(frame->returnFrameName());
-                item->setToolTip(frame->returnFrameName());
+                QImage testimage_1(QString(":/images/NO_inactive%1.svg").arg(i+1));
+                QImage testimage_2(":/images/done_inactive.svg");
+                // 因为没有设置自定义的spacing，所以使用的是item的默认spacing，这里通过dstyleditemdelegate源码得知默认的spacing为DStyle::PM_ContentsSpacing
+                int itemimagewidth = m_frameLabelsView->itemSize().width()
+                        - testimage_1.width() - testimage_2.width()
+                        - m_frameLabelsView->itemMargins().left() - m_frameLabelsView->itemMargins().right()
+                        - (DStyleHelper(qApp->style()).pixelMetric(DStyle::PM_ContentsSpacing) * 2);
+                SetItemTextAndTooltip(item, frame->returnFrameName(), itemimagewidth);
             }
         }
-    }
-    else {
+
+        confirm_quit_frame_->setTitle(::QObject::tr("Abort Installation"));
+        confirm_quit_frame_->setComment(::QObject::tr("Relevant operations you made in the installation process will not take effect, abort or continue installation?"));
+        confirm_quit_frame_->setCancelButtonText(::QObject::tr("Continue"));
+        confirm_quit_frame_->setEnterButtonText(::QObject::tr("Abort"));
+
+    } else {
         QWidget::changeEvent(event);
     }
 }
@@ -420,11 +461,11 @@ void MainWindow::changeEvent(QEvent *event)
 void MainWindow::initConnections() {
   connect(close_button_, &DIconButton::clicked, this, &MainWindow::onCloseEvent);
 
-  connect(confirm_quit_frame_, &ConfirmQuitFrame::quitCancelled, this, [=](){
-             confirm_quit_frame_->close();
+  connect(confirm_quit_frame_, &WarnningFrame::quitCanceled, this, [=](){
+             hideChildFrame();
              qApp->setActiveWindow(this);
           });
-  connect(confirm_quit_frame_, &ConfirmQuitFrame::quitConfirmed,
+  connect(confirm_quit_frame_, &WarnningFrame::quitEntered,
           this, &MainWindow::shutdownSystem);
 
   connect(control_panel_frame_, &ControlPanelFrame::currentPageChanged,
@@ -440,6 +481,7 @@ void MainWindow::initConnections() {
 
   connect(partition_frame_, &PartitionFrame::reboot,
           this, &MainWindow::rebootSystem);
+
   connect(partition_frame_, &PartitionFrame::coverMainWindowFrameLabelsView, this, [=] (bool cover) {
       updateFrameLabelPreviousState(!cover);
   });
@@ -484,7 +526,13 @@ void MainWindow::initConnections() {
           , &MainWindow::setCloseButtonVisible);
   connect(m_installResultsFrame, &InstallResultsFrame::updateQuitFrameTs, this, [=] (bool result) {
       if (result) {
-          confirm_quit_frame_->updateTsForSuccessPage();
+          confirm_quit_frame_->setTitle(::QObject::tr("Shut Down"));
+          confirm_quit_frame_->setComment(::QObject::tr("You can experience it after configuring user information in next system startup."));
+          confirm_quit_frame_->setCancelButtonText(::QObject::tr("Cancel"));
+          confirm_quit_frame_->setEnterButtonText(::QObject::tr("Shut Down"));
+          confirm_quit_frame_->setEnterButtonStyle("QPushButton{ color:#414D68; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(230, 230, 230); } \
+                                              QPushButton:hover{ color:#414D68; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(205, 205, 205); } \
+                                            QPushButton:pressed{ color:#0081FF; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(188, 196, 208); }");
       }
   });
 
@@ -498,18 +546,21 @@ void MainWindow::initConnections() {
     this->close();
   });
 
-  // 主窗口分辨率适配
-  connect(ScreenAdaptationManager::instance(),
-          &ScreenAdaptationManager::primaryAvailableGetometryChanaged,
-          this, [=](const QRect &rect) {
-      this->setFixedSize(rect.size());
-      this->adjustSize();
-  });
+//  // 主窗口分辨率适配
+//  connect(ScreenAdaptationManager::instance(),
+//          &ScreenAdaptationManager::primaryAvailableGetometryChanaged,
+//          this, [=](const QRect &rect) {
+//      this->setFixedSize(rect.size());
+//      this->adjustSize();
+//  });
 }
 
 void MainWindow::initPages() {
-  confirm_quit_frame_ = new ConfirmQuitFrame(this);
+  confirm_quit_frame_ = new WarnningFrame(this);
   confirm_quit_frame_->setFocusPolicy(Qt::NoFocus);
+  confirm_quit_frame_->setEnterButtonStyle("QPushButton{ color:#FF5736; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(230, 230, 230); } \
+                                      QPushButton:hover{ color:#FF5736; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(205, 205, 205); } \
+                                    QPushButton:pressed{ color:#A40020; border:1px solid; border-color:rgba(0, 0, 0, 0.03); border-radius:8px; background-color:rgb(188, 196, 208); }");
   confirm_quit_frame_->hide();
 
   m_repairSystemFrame = new RepairSystemFrame(this);
@@ -595,6 +646,7 @@ void MainWindow::initPages() {
   m_frameLabelsModel = new QStandardItemModel();
   m_frameLabelsView->setModel(m_frameLabelsModel);
   m_frameLabelsView->setItemMargins(QMargins(10,0,10,0));
+  m_frameLabelsView->setTextElideMode(Qt::ElideNone);//这个是禁用listview提供的字符省略方案
 
   m_frameSelectedLayout->addWidget(m_frameLabelsView, 0, Qt::AlignHCenter | Qt::AlignVCenter);
 
@@ -616,8 +668,14 @@ void MainWindow::constructLabelView()
         item->setIcon(QIcon(pixPathTemplate.arg(i)));
         ++i;
 
-        item->setText(tr(frame->returnFrameName().toLatin1().data()));
-        item->setToolTip(frame->returnFrameName());
+        QImage testimage_1(pixPathTemplate.arg(i));
+        QImage testimage_2(":/images/done_inactive.svg");
+        // 因为没有设置自定义的spacing，所以使用的是item的默认spacing，这里通过dstyleditemdelegate源码得知默认的spacing为DStyle::PM_ContentsSpacing
+        int itemimagewidth = m_frameLabelsView->itemSize().width()
+                - testimage_1.width() - testimage_2.width()
+                - m_frameLabelsView->itemMargins().left() - m_frameLabelsView->itemMargins().right()
+                - (DStyleHelper(qApp->style()).pixelMetric(DStyle::PM_ContentsSpacing) * 2);
+        SetItemTextAndTooltip(item, frame->returnFrameName(), itemimagewidth);
 
         QVariant framePointer = QVariant::fromValue(frame);
         item->setData(framePointer, FramePointerRole);
@@ -651,6 +709,7 @@ void MainWindow::initUI() {
 
   // TODO: use titleBar implement.
   close_button_ = new DIconButton(this);
+  close_button_->setFocusPolicy(Qt::NoFocus);
   close_button_->setObjectName("close_button");
   close_button_->setFixedSize(50, 50);
   close_button_->setIconSize(QSize(50, 50));
@@ -711,8 +770,8 @@ void MainWindow::initUI() {
 
   back_button_->raise();
 
+  shadow_widget = new ShadowWidget(this);
   shadow_widget->hide();
-  shadow_widget->setFocusPolicy(Qt::NoFocus);
 }
 
 void MainWindow::registerShortcut() {
@@ -777,6 +836,7 @@ void MainWindow::setWindowIcon(const QString &path)
 
         QLabel *windowLabel = new QLabel;
         windowLabel->setFixedSize(iconSize, iconSize);
+        windowLabel->setScaledContents(true);
         windowLabel->setPixmap(pixmap);
         windowLabel->setParent(this);
         windowLabel->raise();
@@ -913,13 +973,13 @@ void MainWindow::rebootSystem() {
 void MainWindow::shutdownSystem() {
   this->saveLogFile();
 
-  if (!ShutdownSystem()) {
-      qWarning() << "ShutdownSystem() failed!";
-  }
+    if (!ShutdownSystem()) {
+        qWarning() << "ShutdownSystem() failed!";
+    }
 
-  if (!ShutdownSystemWithMagicKey()) {
-      qWarning() << "ShutdownSystemWithMagicKey() failed!";
-  }
+    if (!PoweroffSystem()) {
+        qWarning() << "PoweroffSystem() failed!";
+    }
 
 }
 
